

# Load libraries ----------------------------------------------------------

library(readr)
library(here)
library(metafor)
library(clubSandwich)
library(dplyr)
library(tidyr)
#install.packages("janitor")
library(janitor)
#install.packages("kableExtra")
library(kableExtra)


# Load data ---------------------------------------------------------------

effect_sizes <- read_csv(
  here("", "effect_sizes.csv"),
  col_types = cols(
    effect_size_id = col_integer(),
    sample_size = col_integer(),
    cognitive_level = col_factor(),
    rob_1_participants = col_factor(levels = c("Low risk", "Unclear risk", "High risk")),
    rob_2_confounding = col_factor(levels = c("Low risk", "Unclear risk", "High risk")),
    rob_3_measurment = col_factor(levels = c("Low risk", "Unclear risk", "High risk")),
    rob_4_blinding = col_factor(levels = c("Low risk", "Unclear risk", "High risk")),
    rob_5_incomplete = col_factor(levels = c("Low risk", "Unclear risk", "High risk")),
    rob_6_selective = col_factor(levels = c("Low risk", "Unclear risk", "High risk"))
  ) 
)


# Table

x <- effect_sizes |> 
  select(study_id, cognitive_level, contains("rob")) |> 
  distinct() |> 
  pivot_longer(contains("rob")) |> 
  tabyl(value, name, cognitive_level) |> 
  adorn_percentages("row") |> 
  adorn_pct_formatting(digits = 0) |>
  adorn_ns(position = "front")



## risk of bias table

effect_sizes |> 
  select(study_id, contains("rob")) |> 
  distinct() |> 
  pivot_longer(contains("rob")) |> 
  tabyl(value, name) |> 
  adorn_percentages("row") |> 
  adorn_pct_formatting(digits = 0) |>
  adorn_ns(position = "front") |> 
  kable() |> 
  kable_paper(full_width = F)



## Create the overall model (no moderator)
overall_model <- rma.mv(
  yi = es,
  V = var,
  slab = reference,
  data = effect_sizes,
  random = ~ 1 | study_id / effect_size_id,
  sparse = TRUE
)

rob_1_mod <- update(
  overall_model,
  mods = ~ rob_1_participants,
  sparse = TRUE
)

rob_2_mod <- update(
  overall_model,
  mods = ~ rob_2_confounding,
  sparse = TRUE
)

rob_3_mod <- update(
  overall_model,
  mods = ~ rob_3_measurment,
  sparse = TRUE
)

rob_4_mod <- update(
  overall_model,
  mods = ~ rob_4_blinding,
  sparse = TRUE
)

rob_5_mod <- update(
  overall_model,
  mods = ~ rob_5_incomplete,
  sparse = TRUE
)

rob_6_mod <- update(
  overall_model,
  mods = ~ rob_6_selective,
  sparse = TRUE
)


## Dimension 1  participants
# (constrain_zero(2) one of the three risks is 0, constrain_zero(2:3) none of the three risks is 0)

rob_1_mod <- update(
  overall_model,
  mods = ~ rob_1_participants,
  sparse = TRUE
)

Wald_test(
  rob_1_mod,
  constraints = constrain_zero(1),
  cluster = effect_sizes$study_id,
  vcov = "CR2"
)


## Dimension 2    confounding


rob_2_mod <- update(
  overall_model,
  mods = ~ rob_2_confounding,
  sparse = TRUE
)
Wald_test(
  rob_2_mod,
  constraints = constrain_zero(2:3),
  cluster = effect_sizes$study_id,
  vcov = "CR2"
)


## Dimension 3    measurement


rob_3_mod <- update(
  overall_model,
  mods = ~ rob_3_measurment,
  sparse = TRUE
)
Wald_test(
  rob_3_mod,
  constraints = constrain_zero(2),
  cluster = effect_sizes$study_id,
  vcov = "CR2"
)


## Dimension 4    blinding


rob_4_mod <- update(
  overall_model,
  mods = ~ rob_4_blinding,
  sparse = TRUE
)

Wald_test(
  rob_4_mod,
  constraints = constrain_zero(2),
  cluster = effect_sizes$study_id,
  vcov = "CR2"
)


## Dimension 5    incomplete


rob_5_mod <- update(
  overall_model,
  mods = ~ rob_5_incomplete,
  sparse = TRUE
)

Wald_test(
  rob_5_mod,
  constraints = constrain_zero(2),
  cluster = effect_sizes$study_id,
  vcov = "CR2"
)


## Dimension 6    selective


rob_6_mod <- update(
  overall_model,
  mods = ~ rob_6_selective,
  sparse = TRUE
)

Wald_test(
  rob_6_mod,
  constraints = constrain_zero(2),
  cluster = effect_sizes$study_id,
  vcov = "CR2"
)


summary(rob_1_mod)
summary(rob_2_mod)
summary(rob_3_mod)
summary(rob_4_mod)
summary(rob_5_mod)
summary(rob_6_mod)
