

# Load packages -----------------------------------------------------------

library(readr)
library(here)
library(metafor)
library(dplyr)
library(tidyr)
library(ggplot2)
library(clubSandwich)
library(stringr)
library(forcats)
#install.packages("patchwork")
library(patchwork)
#install.packages("ggtext")
library(ggtext)


# Setup themes ------------------------------------------------------------
theme_es <- theme_bw(base_size = 9) +
  theme(
    axis.text = element_text(size = 9, colour = "black"),
    axis.text.y = element_markdown(size = 9, colour = "black"),
    panel.border = element_blank(),
    axis.line.x = element_line(),
    axis.title.y = element_blank(),
    axis.ticks.y = element_blank(),
    axis.ticks.length.y = unit(0, "pt"),
    panel.grid = element_blank(),
    strip.background = element_blank(),
    strip.text = element_blank(),
    plot.margin = margin(0, 0, 0, 0)
  )

theme_table <- theme_minimal() +
  theme_bw(base_size = 9) +
  theme(
    plot.title = element_text(size = 9, colour = "black", hjust = .5),
    panel.border = element_blank(),
    axis.text = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    axis.ticks.length = unit(0, "pt"),
    panel.grid = element_blank(),
    strip.background = element_blank(),
    strip.text = element_blank(),
    plot.margin = margin(0, 0, 0, 0)
  )

theme_es_decision <- theme_bw(base_size = 7) +
  theme(
    axis.text = element_text(size = 7, colour = "black"),
    axis.text.y = element_markdown(size = 7, colour = "black"),
    panel.border = element_blank(),
    axis.line.x = element_line(),
    axis.title.y = element_blank(),
    axis.ticks.y = element_blank(),
    axis.ticks.length.y = unit(0, "pt"),
    panel.grid = element_blank(),
    strip.background = element_blank(),
    strip.text = element_blank(),
    plot.margin = margin(0, 0, 0, 0)
  )

theme_table_decision <- theme_minimal() +
  theme_bw(base_size = 7) +
  theme(
    plot.title = element_text(size = 7, colour = "black", hjust = .5),
    panel.border = element_blank(),
    axis.text = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    axis.ticks.length = unit(0, "pt"),
    panel.grid = element_blank(),
    strip.background = element_blank(),
    strip.text = element_blank(),
    plot.margin = margin(0, 0, 0, 0)
  )

# Load data ---------------------------------------------------------------

effect_sizes <- read_csv(here("", "effect_sizes.csv"))



# all -----------------------------------------------------------------
# basic foest plot： effect_sizes_basic <- effect_sizes |> filter(cognitive_level == "Basic cognition")

effect_sizes_all <- effect_sizes

# Fit model
all_model <- rma.mv(
  yi = es,
  V = var,
  slab = reference,
  data = effect_sizes_all,
  random = ~ 1 | study_id / effect_size_id,
  sparse = TRUE
)

# Extract effect size and ci
all_result <- conf_int(
  all_model,
  vcov = "CR2",
  cluster = effect_sizes_all$study_id,
  tidy = TRUE
) |>
  as_tibble() |>
  transmute(
    type = "overall",
    reference = "**Overall estimate**",
    estimate = beta,
    conf.low = CI_L,
    conf.high = CI_U
  )

## Pool per study ---------------------------------------------------------

# Random model per study

all_ind_studies_mods <- effect_sizes_all |>
  nest_by(study_id, reference) |>
  mutate(
    mod = list(
      rma(
        yi = es,
        vi = var,
        method = "REML",
        data = data
      )
    )
  )

all_ind_studies <- all_ind_studies_mods |>
  summarise(broom::tidy(mod, conf.int = TRUE))

# Get weights
all_weights_vec <- weights(all_model)

all_weights <- tibble(
  reference = names(all_weights_vec),
  weight = all_weights_vec
) |>
  mutate(reference = str_remove(reference, "\\.[:digit:]{1,2}")) |>
  group_by(reference) |>
  summarise(weight = sum(weight))

# Merge
all_ind_studies <- all_ind_studies |>
  select(study_id, reference, estimate, conf.low, conf.high) |>
  left_join(all_weights, by = "reference") |>
  ungroup() |>
  mutate(
    type = "individual",
    std_wts = weight / max(weight)
  )

all_data <- all_ind_studies |>
  bind_rows(all_result)

## Plot --------------------------------------------------------------------
# Plot ES
all_plot1 <- all_data |>
  ggplot(aes(x = estimate, xmin = conf.low, xmax = conf.high, y = reorder(reference, desc(estimate),decreasing=TRUE))) +
  geom_vline(xintercept = 0, color = "gray50") +
  geom_point(aes(size = std_wts), show.legend = FALSE, shape = "square",na.rm=TRUE) +
  geom_point(
    data = all_result,
    size = 2.5
  ) +
  geom_linerange(
    data = all_result,
    size = 1.5
  ) +
  geom_linerange() +
  scale_size_area(max_size = 3) +
  facet_grid(rows = vars(type), scales = "free_y", space = "free_y") +
  xlab(NULL) +
  theme_es

# Plot stats
all_stats_plot <- all_data |>
  mutate(
    across(c(estimate, conf.low, conf.high, weight), ~ format(round(.x, 2), nsmall = 2)),
    conf = paste0("[", conf.low, ", ", conf.high, "]"),
    weight = gsub("NA", "", weight),
    face = if_else(type == "overall", "bold", "plain")
  )


# Convert ESTIMATE from characters to numeric values, demined in descending order of magnitude.
all_plot2 <- all_stats_plot |>
  ggplot(
    aes(x = "a", y = reorder(reference, -as.numeric(estimate), decreasing=TRUE), label = estimate)
  ) +
  geom_text(aes(fontface = face), size = 9 * 0.36, hjust = 1, nudge_x = .25) +
  ggtitle(expression(~italic("g"))) +
  facet_grid(rows = vars(type), scales = "free_y", space = "free_y") +
  theme_table


all_plot3 <- all_stats_plot |>
  ggplot(
    aes(x = "a",y = reorder(reference, -as.numeric(estimate), decreasing=TRUE), label = conf)
  ) +
  geom_text(aes(fontface = face), size = 9 * 0.36) +
  ggtitle("95% CI") +
  facet_grid(rows = vars(type), scales = "free_y", space = "free_y") +
  theme_table

all_plot4 <- all_stats_plot |>
  ggplot(
    aes(x = "a",y = reorder(reference, -as.numeric(estimate), decreasing=TRUE), label = weight)
  ) +
  geom_text(aes(fontface = face), size = 9 * 0.36, hjust = 1, nudge_x = .25) +
  ggtitle("Weight") +
  facet_grid(rows = vars(type), scales = "free_y", space = "free_y") +
  theme_table


(all_plot_combine <- all_plot1 + all_plot2 + all_plot3 + all_plot4 +
    plot_layout(ncol = 4, width = c(6, 1, 2, 1)))

ggsave(
  plot = all_plot_combine,
  filename = "all_forest.png",
  device = "png",
  path = here(""),
  width = 17.5,
  height = 22,
  units = "cm"
)


